@@ -27,15 +27,10 @@ kable = Kable({
 })
 
 
-@app.route('/authenticateRequest')
-@kable.authenticateRequest
+@app.route('/authenticate')
+@kable.authenticate
 def authenticated():
-    return "hello world - authenticate request"
-
-@app.route('/recordRequest')
-@kable.recordRequest
-def recorded():
-    return "hello world - recorded request"
+    return "hello world - authenticate"
 
 @app.route('/record')
 def recordData():
